@@ -1,8 +1,10 @@
 import edgeimpulse.model
-import edgeimpulse.util
+import edgeimpulse.exceptions
 
 import os
 
+__version__ = "0.1.0"
+
 try:
     API_KEY = os.environ["EI_API_KEY"]
 except KeyError:
